height property

double? height
final

Fixed height for the chart widget.

When null, the height is calculated automatically based on the screen width and whether the legend is shown.

Implementation

final double? height;