ColorSeed enum

The colors to use on sectors of donut chart and bars of bar chart

Inheritance
Available extensions

Values

lightRed → const ColorSeed

Color option

const ColorSeed('Vermelho Claro', Colors.redAccent)
red → const ColorSeed

Color option

const ColorSeed('Vermelho', Colors.red)
pink → const ColorSeed

Color option

const ColorSeed('Rosa', Colors.pink)
purple → const ColorSeed

Color option

const ColorSeed('Púrpura', Colors.purple)
deepPurple → const ColorSeed

Color option

const ColorSeed('Roxo', Colors.deepPurple)
indigo → const ColorSeed

Color option

const ColorSeed('Indigo', Colors.indigo)
blue → const ColorSeed

Color option

const ColorSeed('Azul', Colors.blue)
brightBlue → const ColorSeed

Color option

const ColorSeed('Azul Claro', Colors.lightBlue)
cyan → const ColorSeed

Color option

const ColorSeed('Ciano', Colors.cyan)
teal → const ColorSeed

Color option

const ColorSeed('Teal', Colors.teal)
green → const ColorSeed

Color option

const ColorSeed('Verde', Colors.green)
lightGreen → const ColorSeed

Color option

const ColorSeed('Verde Claro', Colors.lightGreen)
lime → const ColorSeed

Color option

const ColorSeed('Lima', Colors.lime)
yellow → const ColorSeed

Color option

const ColorSeed('Amarelo', Colors.yellow)
amber → const ColorSeed

Color option

const ColorSeed('Ambar', Colors.amber)
orange → const ColorSeed

Color option

const ColorSeed('Laranja', Colors.orange)
deepOrange → const ColorSeed

Color option

const ColorSeed('Laranja Escuro', Colors.deepOrange)
brown → const ColorSeed

Color option

const ColorSeed('Marrom', Colors.brown)
grey → const ColorSeed

Color option

const ColorSeed('Cinza', Colors.grey)
blueGrey → const ColorSeed

Color option

const ColorSeed('Cinza escuro', Colors.blueGrey)

Properties

color Color
The Color option
final
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
label String
Color description
final
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ColorSeed>
A constant List of the values in this enum, in order of their declaration.