DataItem class

The data type to donut and bar chart

Constructors

DataItem({required dynamic id, required String label, required double value, bool selected = false})
Dataset type

Properties

hashCode int
The hash code for this object.
no setterinherited
id ↔ dynamic
The id of each dataset item
getter/setter pair
label String
The label of each dataset item
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selected bool
Not used yet, for future updates
getter/setter pair
value double
The value of each dataset tiem
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited