BarChartPainter class
Paints the bars, labels, title, legend, and grid lines for a BarChart.
- Inheritance
-
- Object
- Listenable
- CustomPainter
- BarChartPainter
Constructors
-
BarChartPainter(List<
DataItem> dataset, BuildContext context, {required Animation<double> animation, String title = '', required List<Color> customColors, Color? backGroundColor, bool showTitle = true, bool showLabels = true, bool showLegend = true, bool showLines = true, required Function onTap}) - Creates a BarChartPainter.
Properties
-
animation
→ Animation<
double> -
Animation driving the entry of the bars.
final
- backGroundColor → Color?
-
Optional background color (currently used by the chart container).
final
- context → BuildContext
-
Build context used for theming and tap detection.
final
-
customColors
→ List<
Color> -
Fallback color palette for bars.
final
-
dataset
→ List<
DataItem> -
Dataset used to render the chart.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- onTap → Function
-
Tap callback triggered when a bar is tapped.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticsBuilder → SemanticsBuilderCallback?
-
Returns a function that builds semantic information for the picture drawn
by this painter.
no setterinherited
- showLabels → bool
-
Whether to show rotated labels for each bar.
final
- showLegend → bool
-
Whether to show the legend below the chart.
final
- showLines → bool
-
Whether to draw horizontal grid lines.
final
- showTitle → bool
-
Whether to show the title.
final
- title → String
-
Title displayed at the top of the chart.
final
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be notified when it is time to repaint.
inherited
-
drawBars(
TouchyCanvas touchyCanvas, Paint paint, Size size, double barWidth, double maxHeight, List< DataItem> dataset, DataItem greaterDataset, double t, List<Color> palette) → void - Draws the chart bars and wires up tap handling.
-
drawLabel(
Canvas canvas, Size size, double barWidth, double maxHeight, List< DataItem> dataset, DataItem greaterDataset, double t, List<Color> palette) → void - Draws rotated labels near each bar.
-
drawLegend(
Canvas canvas, Size size, List< DataItem> dataset, double t, List<Color> palette) → void - Draws the legend below the chart.
-
drawLines(
Canvas canvas, Size size, double maxHeight) → void - Draws the main axis line and grid lines.
-
drawTitle(
Canvas canvas, Size size) → void - Draws the chart title.
-
hitTest(
Offset position) → bool? -
Called whenever a hit test is being performed on an object that is using
this custom paint delegate.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
paint(
Canvas canvas, Size size) → void -
Called whenever the object needs to paint. The given Canvas has its
coordinate space configured such that the origin is at the top left of the
box. The area of the box is the size of the
sizeargument.override -
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that the
object notifies when it is time to repaint.
inherited
-
shouldRebuildSemantics(
covariant CustomPainter oldDelegate) → bool -
Called whenever a new instance of the custom painter delegate class is
provided to the RenderCustomPaint object, or any time that a new
CustomPaint object is created with a new instance of the custom painter
delegate class (which amounts to the same thing, because the latter is
implemented in terms of the former).
inherited
-
shouldRepaint(
covariant CustomPainter oldDelegate) → bool -
Returns whether this painter should repaint.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited