showCenterText property
Whether to display text in the center of the donut. When true, displays the total value of all items. Defaults to true.
Implementation
final bool showCenterText;
Whether to display text in the center of the donut. When true, displays the total value of all items. Defaults to true.
final bool showCenterText;