ColorSeed enum
Values
- lightRed → const ColorSeed
-
const ColorSeed('Vermelho Claro', Colors.redAccent) - red → const ColorSeed
-
const ColorSeed('Vermelho', Colors.red) - pink → const ColorSeed
-
const ColorSeed('Rosa', Colors.pink) - purple → const ColorSeed
-
const ColorSeed('Púrpura', Colors.purple) - deepPurple → const ColorSeed
-
const ColorSeed('Roxo', Colors.deepPurple) - indigo → const ColorSeed
-
const ColorSeed('Indigo', Colors.indigo) - blue → const ColorSeed
-
const ColorSeed('Azul', Colors.blue) - brightBlue → const ColorSeed
-
const ColorSeed('Azul Claro', Colors.lightBlue) - cyan → const ColorSeed
-
const ColorSeed('Ciano', Colors.cyan) - teal → const ColorSeed
-
const ColorSeed('Teal', Colors.teal) - green → const ColorSeed
-
const ColorSeed('Verde', Colors.green) - lightGreen → const ColorSeed
-
const ColorSeed('Verde Claro', Colors.lightGreen) - lime → const ColorSeed
-
const ColorSeed('Lima', Colors.lime) - yellow → const ColorSeed
-
const ColorSeed('Amarelo', Colors.yellow) - amber → const ColorSeed
-
const ColorSeed('Ambar', Colors.amber) - orange → const ColorSeed
-
const ColorSeed('Laranja', Colors.orange) - deepOrange → const ColorSeed
-
const ColorSeed('Laranja Escuro', Colors.deepOrange) - brown → const ColorSeed
-
const ColorSeed('Marrom', Colors.brown) - grey → const ColorSeed
-
const ColorSeed('Cinza', Colors.grey) - blueGrey → const ColorSeed
-
const ColorSeed('Cinza escuro', Colors.blueGrey)
Properties
- color → Color
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- label → String
-
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited